@@ -2,7 +2,7 @@ package Teng;
 use strict;
 use warnings;
 use Carp ();
-use Class::Load ();
+use Class::Load 0.06 ();
 use DBI 1.33;
 use Scalar::Util;
 use SQL::Maker::SQLType qw(sql_type);
@@ -11,7 +11,7 @@ use Teng::Iterator;
 use Teng::Schema;
 use DBIx::TransactionManager 1.06;
 use Teng::QueryBuilder;
-use Class::Accessor::Lite
+use Class::Accessor::Lite 0.05
    rw => [ qw(
         connect_info
         on_connect_do
@@ -26,7 +26,7 @@ use Class::Accessor::Lite
     )]
 ;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 sub load_plugin {
     my ($class, $pkg, $opt) = @_;
@@ -276,7 +276,9 @@ sub execute {
             if (Scalar::Util::blessed($v) && ref($v) eq 'SQL::Maker::SQLType') {
                 $sth->bind_param($i++, ${$v->value_ref}, $v->type);
             } else {
-                $sth->bind_param( $i++, $v);
+                # allow array ref for using pg_types. e.g. [ $value => { pg_type => PG_BYTEA } ]
+                # ref. https://metacpan.org/pod/DBD::Pg#quote
+                $sth->bind_param( $i++, ref($v) eq 'ARRAY' ? @$v : $v );
             }
         }
         $sth->execute();
@@ -290,13 +292,17 @@ sub execute {
 }
 
 sub _last_insert_id {
-    my ($self, $table_name) = @_;
+    my ($self, $table_name, $column) = @_;
 
     my $driver = $self->{driver_name};
     if ( $driver eq 'mysql' ) {
         return $self->dbh->{mysql_insertid};
     } elsif ( $driver eq 'Pg' ) {
-        return $self->dbh->last_insert_id( undef, undef, undef, undef,{ sequence => join( '_', $table_name, 'id', 'seq' ) } );
+        if (defined $column) {
+            return $self->dbh->last_insert_id( undef, undef, undef, undef,{ sequence => join( '_', $table_name, $column, 'seq' ) } );
+        } else {
+            return $self->dbh->last_insert_id( undef, undef, $table_name, undef);
+        }
     } elsif ( $driver eq 'SQLite' ) {
         return $self->dbh->func('last_insert_rowid');
     } elsif ( $driver eq 'Oracle' ) {
@@ -341,6 +347,7 @@ sub fast_insert {
     my ($self, $table_name, $args, $prefix) = @_;
 
     $self->do_insert($table_name, $args, $prefix);
+    # XXX in Pg, _last_insert_id has potential failure when inserting to non Serial table or explicitly inserting Serrial id
     $self->_last_insert_id($table_name);
 }
 
@@ -355,7 +362,7 @@ sub insert {
 
     my @missing_primary_keys = grep { not defined $args->{$_} } @$pk;
     if (@missing_primary_keys == 1) {
-        $args->{$missing_primary_keys[0]} = $self->_last_insert_id($table_name);
+        $args->{$missing_primary_keys[0]} = $self->_last_insert_id($table_name, $missing_primary_keys[0]);
     }
 
     return $args if $self->suppress_row_objects;
@@ -831,7 +838,7 @@ You must pass C<connect_info> or C<dbh> to the constructor.
 
 =item * C<dbh>
 
-Specifies the database handle to use. 
+Specifies the database handle to use.
 
 =item * C<no_ping>
 
@@ -845,7 +852,7 @@ specific DBI.pm's FetchHashKeyName.
 =item * C<schema>
 
 Specifies the Teng::Schema instance to use.
-If not specified, the value specified in C<schema_class> is loaded and 
+If not specified, the value specified in C<schema_class> is loaded and
 instantiated for you.
 
 =item * C<schema_class>
@@ -910,6 +917,10 @@ insert new record and get last_insert_id.
 
 no creation row object.
 
+=item C<< $teng->do_insert >>
+
+Internal method called from C<insert> and C<fast_insert>. You can hook it on your responsibility.
+
 =item C<$teng-E<gt>bulk_insert($table_name, \@rows_data, \%opt)>
 
 Accepts either an arrayref of hashrefs.
@@ -1163,6 +1174,18 @@ BulkInsert's "bulk_insert" method is imported as "insert_bulk".
 
 handling error method.
 
+=item C<< $teng->connected >>
+
+check connected or not.
+
+=item C<< $teng->reconnect >>
+
+reconnect database
+
+=item C<< $teng->mode >>
+
+DEPRECATED AND *WILL* BE REMOVED. PLEASE USE C< no_ping > option.
+
 =item How do you use display the profiling result?
 
 use L<Devel::KYTProf>.
